# -*- coding: utf-8 -*-
# Copyright 2021, CS GROUP - France, http://www.c-s.fr
#
# This file is part of EODAG project
#     https://www.github.com/CS-SI/EODAG
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""EODAG-cube: Data access for EODAG."""

__title__ = "eodag-cube"
__description__ = "Data access for EODAG"
__version__ = "0.3.0"
__author__ = "CS GROUP - France (CSSI)"
__author_email__ = "eodag@csgroup.space"
__url__ = "https://github.com/CS-SI/eodag-cube"
__license__ = "Apache 2.0"
__copyright__ = "Copyright 2021, CS GROUP - France, http://www.c-s.fr"
